==> kpl-2.2.tar.bz2: kpl-2.2/kpl/sourcewidget.cpp <==
/***************************************************************************
                          sourcewidget.cpp  -  description
                             -------------------
    begin                : Sun Apr 16 2000
    copyright            : (C) 2001 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qtextstream.h>
#include <qfile.h>
#include <qtimer.h>
#include <kglobalsettings.h>
#include "sourcewidget.h"

SourceWidget::SourceWidget(QWidget* parent, QFile* f) :
 QMultiLineEdit(parent), line(0), col1(-1), col2(0)
{
  setFont(KGlobalSettings::fixedFont());
  setReadOnly(true);
  if (f)
    fill(f);
}

SourceWidget::~SourceWidget()
{
}

void SourceWidget::fill(QFile *f)
{
  setAutoUpdate(false);
  clear();
  QTextStream t(f);
  while (!t.eof())
    append(t.readLine());
  f->close();
  setAutoUpdate(true);
  repaint();
}

void SourceWidget::highlight(const QString& func)
{
  if (func.isEmpty())
    return;
  line = -1;
  while (QString s = textLine(++line)) {
    col1 = s.find(QString(" ") + func + "(double");
    if (col1 != -1) {
      col1++;
      col2 = col1 + func.length();
      slotHighlight();
      break;
    }
  }
  setFocus();
}

void SourceWidget::slotHighlight()
{
  if (col1 > 0) {
    setCursorPosition(line + 15, col1);
    setCursorPosition(line, col1);
    setCursorPosition(line, col2, true);
  }
}

==> kpl-3.0.tar.bz2: kpl-3.0/kpl/sourcewidget.cpp <==
/***************************************************************************
                          sourcewidget.cpp  -  description
                             -------------------
    begin                : Sun Apr 16 2000
    copyright            : (C) 2002 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qtextstream.h>
#include <qfile.h>
#include <kapp.h>
#include <kglobalsettings.h>
#include "sourcewidget.h"

SourceWidget::SourceWidget(QWidget* _parent, QFile* f) :
 QMultiLineEdit(_parent), line(0), col1(-1), col2(0)
{
  setFont(KGlobalSettings::fixedFont());
  setReadOnly(true);
#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
  setUndoRedoEnabled(false);
  setWordWrap(NoWrap);
#else
  setUndoEnabled(false);
#endif
  if (f)
    fill(f);
}

SourceWidget::~SourceWidget()
{
}

void SourceWidget::fill(QFile *f)
{
  setAutoUpdate(false);
  clear();
#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
  append(QTextStream(f).read());
#else
  QTextStream t(f);
  while (!t.eof())
    append(t.readLine());
#endif
  f->close();
  setAutoUpdate(true);
  repaint();
}

void SourceWidget::highlight(const QString& func)
{
  if (func.isEmpty())
    return;
  line = -1;
  while (QString s = textLine(++line)) {
    col1 = s.find(QString(" ") + func + "(double");
    if (col1 != -1) {
      col1++;
      col2 = col1 + func.length();
      slotHighlight();
      break;
    }
  }
  setFocus();
}

void SourceWidget::slotHighlight()
{
  if (col1 > 0) {
    setCursorPosition(line + 15, col1);
#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
    setSelection(line, col1, line, col2);
#else
    setCursorPosition(line, col1);
    setCursorPosition(line, col2, true);
#endif
  }
}
